;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "mode-line-debug" "20251101.2033"
  "Show status of debug-on-error in mode-line."
  '((emacs  "28.1")
    (compat "30.1"))
  :url "https://github.com/tarsius/mode-line-debug"
  :commit "f68cfa2ea28ce2dc6f40d4c93a44a701510e8e04"
  :revdesc "f68cfa2ea28c"
  :keywords '("convenience" "lisp")
  :authors '(("Jonas Bernoulli" . "emacs.mode-line-debug@jonas.bernoulli.dev"))
  :maintainers '(("Jonas Bernoulli" . "emacs.mode-line-debug@jonas.bernoulli.dev")))
